@@ -1,5 +1,8 @@
 import abc
 
+from easytradesdk.entity.Symbol import Symbol
+from easytradesdk.entity.TC import TC
+
 
 class AbsContext(metaclass=abc.ABCMeta):
 
@@ -30,3 +33,7 @@ class AbsContext(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def getTradeApi(self):
         pass
+
+    @abc.abstractmethod
+    def calculateMaxAvailableBuyQuantity(self, tc: TC, symbol: Symbol, amount=None, offsetPrice=None, scale=2):
+        pass
