@@ -1,4 +1,5 @@
 import decimal
+from datetime import datetime
 
 from easytradesdk.Serializer import DeserializableObject
 
@@ -15,9 +16,14 @@ class DepthValue(DeserializableObject):
 
 class Depth(DeserializableObject):
 
-    def __init__(self):
+    def __init__(self, lastUpdateMills=0):
+        self.lastUpdateMills = lastUpdateMills
         self.bids = []
         self.asks = []
 
     def getObjectMapper(self):
         return {"bids": DepthValue, "asks": DepthValue}
+
+    def getOffsetMills(self):
+        _currentMills = int(round(datetime.now().timestamp() * 1000))
+        return _currentMills - self.lastUpdateMills
